pub struct Input {
pub content: Bundle,
pub async_: Option<FHIRBoolean>,
pub response_url: Option<FHIRUrl>,
}Fields
content: BundleThe message to process (or, if using asynchronous messaging, it may be a response message to accept)
async_: Option<FHIRBoolean>If ‘true’ the message is processed using the asynchronous messaging pattern
response_url: Option<FHIRUrl>A URL to submit response messages to, if asynchronous messaging is being used, and if the MessageHeader.source.endpoint is not the appropriate place to submit responses